MorphHeroicons class abstract final

Every heroicons icon, as a named constant.

import 'package:stroke_morph_icons/heroicons.dart';

MorphIcon(icon: MorphHeroicons.academicCap);

Each icon is its own static const, so an app links only the ones it actually names. byName is the one exception — see its doc.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

academicCap → const NodeIcon
The academic-cap icon.
adjustmentsHorizontal → const NodeIcon
The adjustments-horizontal icon.
adjustmentsVertical → const NodeIcon
The adjustments-vertical icon.
archiveBox → const NodeIcon
The archive-box icon.
archiveBoxArrowDown → const NodeIcon
The archive-box-arrow-down icon.
archiveBoxXMark → const NodeIcon
The archive-box-x-mark icon.
arrowDown → const NodeIcon
The arrow-down icon.
arrowDownCircle → const NodeIcon
The arrow-down-circle icon.
arrowDownLeft → const NodeIcon
The arrow-down-left icon.
arrowDownOnSquare → const NodeIcon
The arrow-down-on-square icon.
arrowDownOnSquareStack → const NodeIcon
The arrow-down-on-square-stack icon.
arrowDownRight → const NodeIcon
The arrow-down-right icon.
arrowDownTray → const NodeIcon
The arrow-down-tray icon.
arrowLeft → const NodeIcon
The arrow-left icon.
arrowLeftCircle → const NodeIcon
The arrow-left-circle icon.
arrowLeftEndOnRectangle → const NodeIcon
The arrow-left-end-on-rectangle icon.
arrowLeftOnRectangle → const NodeIcon
The arrow-left-on-rectangle icon.
arrowLeftStartOnRectangle → const NodeIcon
The arrow-left-start-on-rectangle icon.
arrowLongDown → const NodeIcon
The arrow-long-down icon.
arrowLongLeft → const NodeIcon
The arrow-long-left icon.
arrowLongRight → const NodeIcon
The arrow-long-right icon.
arrowLongUp → const NodeIcon
The arrow-long-up icon.
arrowPath → const NodeIcon
The arrow-path icon.
arrowPathRoundedSquare → const NodeIcon
The arrow-path-rounded-square icon.
arrowRight → const NodeIcon
The arrow-right icon.
arrowRightCircle → const NodeIcon
The arrow-right-circle icon.
arrowRightEndOnRectangle → const NodeIcon
The arrow-right-end-on-rectangle icon.
arrowRightOnRectangle → const NodeIcon
The arrow-right-on-rectangle icon.
arrowRightStartOnRectangle → const NodeIcon
The arrow-right-start-on-rectangle icon.
arrowSmallDown → const NodeIcon
The arrow-small-down icon.
arrowSmallLeft → const NodeIcon
The arrow-small-left icon.
arrowSmallRight → const NodeIcon
The arrow-small-right icon.
arrowSmallUp → const NodeIcon
The arrow-small-up icon.
arrowsPointingIn → const NodeIcon
The arrows-pointing-in icon.
arrowsPointingOut → const NodeIcon
The arrows-pointing-out icon.
arrowsRightLeft → const NodeIcon
The arrows-right-left icon.
arrowsUpDown → const NodeIcon
The arrows-up-down icon.
arrowTopRightOnSquare → const NodeIcon
The arrow-top-right-on-square icon.
arrowTrendingDown → const NodeIcon
The arrow-trending-down icon.
arrowTrendingUp → const NodeIcon
The arrow-trending-up icon.
arrowTurnDownLeft → const NodeIcon
The arrow-turn-down-left icon.
arrowTurnDownRight → const NodeIcon
The arrow-turn-down-right icon.
arrowTurnLeftDown → const NodeIcon
The arrow-turn-left-down icon.
arrowTurnLeftUp → const NodeIcon
The arrow-turn-left-up icon.
arrowTurnRightDown → const NodeIcon
The arrow-turn-right-down icon.
arrowTurnRightUp → const NodeIcon
The arrow-turn-right-up icon.
arrowTurnUpLeft → const NodeIcon
The arrow-turn-up-left icon.
arrowTurnUpRight → const NodeIcon
The arrow-turn-up-right icon.
arrowUp → const NodeIcon
The arrow-up icon.
arrowUpCircle → const NodeIcon
The arrow-up-circle icon.
arrowUpLeft → const NodeIcon
The arrow-up-left icon.
arrowUpOnSquare → const NodeIcon
The arrow-up-on-square icon.
arrowUpOnSquareStack → const NodeIcon
The arrow-up-on-square-stack icon.
arrowUpRight → const NodeIcon
The arrow-up-right icon.
arrowUpTray → const NodeIcon
The arrow-up-tray icon.
arrowUturnDown → const NodeIcon
The arrow-uturn-down icon.
arrowUturnLeft → const NodeIcon
The arrow-uturn-left icon.
arrowUturnRight → const NodeIcon
The arrow-uturn-right icon.
arrowUturnUp → const NodeIcon
The arrow-uturn-up icon.
atSymbol → const NodeIcon
The at-symbol icon.
backspace → const NodeIcon
The backspace icon.
backward → const NodeIcon
The backward icon.
banknotes → const NodeIcon
The banknotes icon.
bars2 → const NodeIcon
The bars-2 icon.
bars3 → const NodeIcon
The bars-3 icon.
bars3BottomLeft → const NodeIcon
The bars-3-bottom-left icon.
bars3BottomRight → const NodeIcon
The bars-3-bottom-right icon.
bars3CenterLeft → const NodeIcon
The bars-3-center-left icon.
bars4 → const NodeIcon
The bars-4 icon.
barsArrowDown → const NodeIcon
The bars-arrow-down icon.
barsArrowUp → const NodeIcon
The bars-arrow-up icon.
battery0 → const NodeIcon
The battery-0 icon.
battery50 → const NodeIcon
The battery-50 icon.
battery100 → const NodeIcon
The battery-100 icon.
beaker → const NodeIcon
The beaker icon.
bell → const NodeIcon
The bell icon.
bellAlert → const NodeIcon
The bell-alert icon.
bellSlash → const NodeIcon
The bell-slash icon.
bellSnooze → const NodeIcon
The bell-snooze icon.
bold → const NodeIcon
The bold icon.
bolt → const NodeIcon
The bolt icon.
boltSlash → const NodeIcon
The bolt-slash icon.
bookmark → const NodeIcon
The bookmark icon.
bookmarkSlash → const NodeIcon
The bookmark-slash icon.
bookmarkSquare → const NodeIcon
The bookmark-square icon.
bookOpen → const NodeIcon
The book-open icon.
briefcase → const NodeIcon
The briefcase icon.
bugAnt → const NodeIcon
The bug-ant icon.
buildingLibrary → const NodeIcon
The building-library icon.
buildingOffice → const NodeIcon
The building-office icon.
buildingOffice2 → const NodeIcon
The building-office-2 icon.
buildingStorefront → const NodeIcon
The building-storefront icon.
byName → const Map<String, MorphIconData>
Every heroicons icon, keyed by its canonical name.
cake → const NodeIcon
The cake icon.
calculator → const NodeIcon
The calculator icon.
calendar → const NodeIcon
The calendar icon.
calendarDateRange → const NodeIcon
The calendar-date-range icon.
calendarDays → const NodeIcon
The calendar-days icon.
camera → const NodeIcon
The camera icon.
chartBar → const NodeIcon
The chart-bar icon.
chartBarSquare → const NodeIcon
The chart-bar-square icon.
chartPie → const NodeIcon
The chart-pie icon.
chatBubbleBottomCenter → const NodeIcon
The chat-bubble-bottom-center icon.
chatBubbleBottomCenterText → const NodeIcon
The chat-bubble-bottom-center-text icon.
chatBubbleLeft → const NodeIcon
The chat-bubble-left icon.
chatBubbleLeftEllipsis → const NodeIcon
The chat-bubble-left-ellipsis icon.
chatBubbleLeftRight → const NodeIcon
The chat-bubble-left-right icon.
chatBubbleOvalLeft → const NodeIcon
The chat-bubble-oval-left icon.
chatBubbleOvalLeftEllipsis → const NodeIcon
The chat-bubble-oval-left-ellipsis icon.
check → const NodeIcon
The check icon.
checkBadge → const NodeIcon
The check-badge icon.
checkCircle → const NodeIcon
The check-circle icon.
chevronDoubleDown → const NodeIcon
The chevron-double-down icon.
chevronDoubleLeft → const NodeIcon
The chevron-double-left icon.
chevronDoubleRight → const NodeIcon
The chevron-double-right icon.
chevronDoubleUp → const NodeIcon
The chevron-double-up icon.
chevronDown → const NodeIcon
The chevron-down icon.
chevronLeft → const NodeIcon
The chevron-left icon.
chevronRight → const NodeIcon
The chevron-right icon.
chevronUp → const NodeIcon
The chevron-up icon.
chevronUpDown → const NodeIcon
The chevron-up-down icon.
circleStack → const NodeIcon
The circle-stack icon.
clipboard → const NodeIcon
The clipboard icon.
clipboardDocument → const NodeIcon
The clipboard-document icon.
clipboardDocumentCheck → const NodeIcon
The clipboard-document-check icon.
clipboardDocumentList → const NodeIcon
The clipboard-document-list icon.
clock → const NodeIcon
The clock icon.
cloud → const NodeIcon
The cloud icon.
cloudArrowDown → const NodeIcon
The cloud-arrow-down icon.
cloudArrowUp → const NodeIcon
The cloud-arrow-up icon.
codeBracket → const NodeIcon
The code-bracket icon.
codeBracketSquare → const NodeIcon
The code-bracket-square icon.
cog → const NodeIcon
The cog icon.
cog6Tooth → const NodeIcon
The cog-6-tooth icon.
cog8Tooth → const NodeIcon
The cog-8-tooth icon.
commandLine → const NodeIcon
The command-line icon.
computerDesktop → const NodeIcon
The computer-desktop icon.
cpuChip → const NodeIcon
The cpu-chip icon.
creditCard → const NodeIcon
The credit-card icon.
cube → const NodeIcon
The cube icon.
cubeTransparent → const NodeIcon
The cube-transparent icon.
currencyBangladeshi → const NodeIcon
The currency-bangladeshi icon.
currencyDollar → const NodeIcon
The currency-dollar icon.
currencyEuro → const NodeIcon
The currency-euro icon.
currencyPound → const NodeIcon
The currency-pound icon.
currencyRupee → const NodeIcon
The currency-rupee icon.
currencyYen → const NodeIcon
The currency-yen icon.
cursorArrowRays → const NodeIcon
The cursor-arrow-rays icon.
cursorArrowRipple → const NodeIcon
The cursor-arrow-ripple icon.
devicePhoneMobile → const NodeIcon
The device-phone-mobile icon.
deviceTablet → const NodeIcon
The device-tablet icon.
divide → const NodeIcon
The divide icon.
document → const NodeIcon
The document icon.
documentArrowDown → const NodeIcon
The document-arrow-down icon.
documentArrowUp → const NodeIcon
The document-arrow-up icon.
documentChartBar → const NodeIcon
The document-chart-bar icon.
documentCheck → const NodeIcon
The document-check icon.
documentCurrencyBangladeshi → const NodeIcon
The document-currency-bangladeshi icon.
documentCurrencyDollar → const NodeIcon
The document-currency-dollar icon.
documentCurrencyEuro → const NodeIcon
The document-currency-euro icon.
documentCurrencyPound → const NodeIcon
The document-currency-pound icon.
documentCurrencyRupee → const NodeIcon
The document-currency-rupee icon.
documentCurrencyYen → const NodeIcon
The document-currency-yen icon.
documentDuplicate → const NodeIcon
The document-duplicate icon.
documentMagnifyingGlass → const NodeIcon
The document-magnifying-glass icon.
documentMinus → const NodeIcon
The document-minus icon.
documentPlus → const NodeIcon
The document-plus icon.
documentText → const NodeIcon
The document-text icon.
ellipsisHorizontal → const NodeIcon
The ellipsis-horizontal icon.
ellipsisHorizontalCircle → const NodeIcon
The ellipsis-horizontal-circle icon.
ellipsisVertical → const NodeIcon
The ellipsis-vertical icon.
envelope → const NodeIcon
The envelope icon.
envelopeOpen → const NodeIcon
The envelope-open icon.
equals → const NodeIcon
The equals icon.
exclamationCircle → const NodeIcon
The exclamation-circle icon.
exclamationTriangle → const NodeIcon
The exclamation-triangle icon.
eye → const NodeIcon
The eye icon.
eyeDropper → const NodeIcon
The eye-dropper icon.
eyeSlash → const NodeIcon
The eye-slash icon.
faceFrown → const NodeIcon
The face-frown icon.
faceSmile → const NodeIcon
The face-smile icon.
film → const NodeIcon
The film icon.
fingerPrint → const NodeIcon
The finger-print icon.
fire → const NodeIcon
The fire icon.
flag → const NodeIcon
The flag icon.
folder → const NodeIcon
The folder icon.
folderArrowDown → const NodeIcon
The folder-arrow-down icon.
folderMinus → const NodeIcon
The folder-minus icon.
folderOpen → const NodeIcon
The folder-open icon.
folderPlus → const NodeIcon
The folder-plus icon.
forward → const NodeIcon
The forward icon.
funnel → const NodeIcon
The funnel icon.
gif → const NodeIcon
The gif icon.
gift → const NodeIcon
The gift icon.
giftTop → const NodeIcon
The gift-top icon.
globeAlt → const NodeIcon
The globe-alt icon.
globeAmericas → const NodeIcon
The globe-americas icon.
globeAsiaAustralia → const NodeIcon
The globe-asia-australia icon.
globeEuropeAfrica → const NodeIcon
The globe-europe-africa icon.
h1 → const NodeIcon
The h1 icon.
h2 → const NodeIcon
The h2 icon.
h3 → const NodeIcon
The h3 icon.
handRaised → const NodeIcon
The hand-raised icon.
handThumbDown → const NodeIcon
The hand-thumb-down icon.
handThumbUp → const NodeIcon
The hand-thumb-up icon.
hashtag → const NodeIcon
The hashtag icon.
heart → const NodeIcon
The heart icon.
home → const NodeIcon
The home icon.
homeModern → const NodeIcon
The home-modern icon.
identification → const NodeIcon
The identification icon.
inbox → const NodeIcon
The inbox icon.
inboxArrowDown → const NodeIcon
The inbox-arrow-down icon.
inboxStack → const NodeIcon
The inbox-stack icon.
informationCircle → const NodeIcon
The information-circle icon.
italic → const NodeIcon
The italic icon.
key → const NodeIcon
The key icon.
language → const NodeIcon
The language icon.
lifebuoy → const NodeIcon
The lifebuoy icon.
lightBulb → const NodeIcon
The light-bulb icon.
The link icon.
linkSlash → const NodeIcon
The link-slash icon.
listBullet → const NodeIcon
The list-bullet icon.
lockClosed → const NodeIcon
The lock-closed icon.
lockOpen → const NodeIcon
The lock-open icon.
magnifyingGlass → const NodeIcon
The magnifying-glass icon.
magnifyingGlassCircle → const NodeIcon
The magnifying-glass-circle icon.
magnifyingGlassMinus → const NodeIcon
The magnifying-glass-minus icon.
magnifyingGlassPlus → const NodeIcon
The magnifying-glass-plus icon.
map → const NodeIcon
The map icon.
mapPin → const NodeIcon
The map-pin icon.
megaphone → const NodeIcon
The megaphone icon.
microphone → const NodeIcon
The microphone icon.
minus → const NodeIcon
The minus icon.
minusCircle → const NodeIcon
The minus-circle icon.
minusSmall → const NodeIcon
The minus-small icon.
moon → const NodeIcon
The moon icon.
musicalNote → const NodeIcon
The musical-note icon.
newspaper → const NodeIcon
The newspaper icon.
noSymbol → const NodeIcon
The no-symbol icon.
numberedList → const NodeIcon
The numbered-list icon.
paintBrush → const NodeIcon
The paint-brush icon.
paperAirplane → const NodeIcon
The paper-airplane icon.
paperClip → const NodeIcon
The paper-clip icon.
pause → const NodeIcon
The pause icon.
pauseCircle → const NodeIcon
The pause-circle icon.
pencil → const NodeIcon
The pencil icon.
pencilSquare → const NodeIcon
The pencil-square icon.
percentBadge → const NodeIcon
The percent-badge icon.
phone → const NodeIcon
The phone icon.
phoneArrowDownLeft → const NodeIcon
The phone-arrow-down-left icon.
phoneArrowUpRight → const NodeIcon
The phone-arrow-up-right icon.
phoneXMark → const NodeIcon
The phone-x-mark icon.
photo → const NodeIcon
The photo icon.
play → const NodeIcon
The play icon.
playCircle → const NodeIcon
The play-circle icon.
playPause → const NodeIcon
The play-pause icon.
plus → const NodeIcon
The plus icon.
plusCircle → const NodeIcon
The plus-circle icon.
plusSmall → const NodeIcon
The plus-small icon.
power → const NodeIcon
The power icon.
presentationChartBar → const NodeIcon
The presentation-chart-bar icon.
presentationChartLine → const NodeIcon
The presentation-chart-line icon.
printer → const NodeIcon
The printer icon.
puzzlePiece → const NodeIcon
The puzzle-piece icon.
qrCode → const NodeIcon
The qr-code icon.
questionMarkCircle → const NodeIcon
The question-mark-circle icon.
queueList → const NodeIcon
The queue-list icon.
radio → const NodeIcon
The radio icon.
receiptPercent → const NodeIcon
The receipt-percent icon.
receiptRefund → const NodeIcon
The receipt-refund icon.
rectangleGroup → const NodeIcon
The rectangle-group icon.
rectangleStack → const NodeIcon
The rectangle-stack icon.
rocketLaunch → const NodeIcon
The rocket-launch icon.
rss → const NodeIcon
The rss icon.
scale → const NodeIcon
The scale icon.
scissors → const NodeIcon
The scissors icon.
server → const NodeIcon
The server icon.
serverStack → const NodeIcon
The server-stack icon.
share → const NodeIcon
The share icon.
shieldCheck → const NodeIcon
The shield-check icon.
shieldExclamation → const NodeIcon
The shield-exclamation icon.
shoppingBag → const NodeIcon
The shopping-bag icon.
shoppingCart → const NodeIcon
The shopping-cart icon.
signal → const NodeIcon
The signal icon.
signalSlash → const NodeIcon
The signal-slash icon.
slash → const NodeIcon
The slash icon.
sparkles → const NodeIcon
The sparkles icon.
speakerWave → const NodeIcon
The speaker-wave icon.
speakerXMark → const NodeIcon
The speaker-x-mark icon.
square2Stack → const NodeIcon
The square-2-stack icon.
square3Stack3d → const NodeIcon
The square-3-stack-3d icon.
squares2x2 → const NodeIcon
The squares-2x2 icon.
squaresPlus → const NodeIcon
The squares-plus icon.
star → const NodeIcon
The star icon.
stop → const NodeIcon
The stop icon.
stopCircle → const NodeIcon
The stop-circle icon.
strikethrough → const NodeIcon
The strikethrough icon.
sun → const NodeIcon
The sun icon.
swatch → const NodeIcon
The swatch icon.
tableCells → const NodeIcon
The table-cells icon.
tag → const NodeIcon
The tag icon.
ticket → const NodeIcon
The ticket icon.
trash → const NodeIcon
The trash icon.
trophy → const NodeIcon
The trophy icon.
truck → const NodeIcon
The truck icon.
tv → const NodeIcon
The tv icon.
underline → const NodeIcon
The underline icon.
user → const NodeIcon
The user icon.
userCircle → const NodeIcon
The user-circle icon.
userGroup → const NodeIcon
The user-group icon.
userMinus → const NodeIcon
The user-minus icon.
userPlus → const NodeIcon
The user-plus icon.
users → const NodeIcon
The users icon.
variable → const NodeIcon
The variable icon.
videoCamera → const NodeIcon
The video-camera icon.
videoCameraSlash → const NodeIcon
The video-camera-slash icon.
viewColumns → const NodeIcon
The view-columns icon.
viewfinderCircle → const NodeIcon
The viewfinder-circle icon.
wallet → const NodeIcon
The wallet icon.
wifi → const NodeIcon
The wifi icon.
window → const NodeIcon
The window icon.
wrench → const NodeIcon
The wrench icon.
wrenchScrewdriver → const NodeIcon
The wrench-screwdriver icon.
xCircle → const NodeIcon
The x-circle icon.
xMark → const NodeIcon
The x-mark icon.