a property
Points of A with the chosen correspondence (if A is a closed loop it may come circularly re-indexed: same points, different cut).
Implementation
final Float64List a;
Points of A with the chosen correspondence (if A is a closed loop it may come circularly re-indexed: same points, different cut).
final Float64List a;