Sampled class final
Subpath sampled at N points by arc length, plus its topology.
This is the currency between resample and plan. An intermediate shape captured mid-flight (an interruption) is also just a list of Sampled.
Constructors
- Sampled(Float64List pts, bool closed)
-
const
Properties
- closed → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pts → Float64List
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited