SpringPreset enum

Spring presets (ζ = c/(2√k)) with the API's public names.

Inheritance
Available extensions

Values

smooth → const SpringPreset

ζ = 1.00 — critically damped, no overshoot.

const SpringPreset(SpringConfig(170, 26))
snappy → const SpringPreset

ζ = 0.73 — fast, subtle overshoot.

const SpringPreset(SpringConfig(420, 30))
bouncy → const SpringPreset

ζ = 0.40 — playful.

const SpringPreset(SpringConfig(300, 14))

Properties

config SpringConfig
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SpringPreset>
A constant List of the values in this enum, in order of their declaration.