dampingRatioOf function
ζ = c / (2√k): 1 is critically damped, below it overshoots, above it crawls.
Implementation
double dampingRatioOf(SpringConfig spring) =>
spring.c / (2 * math.sqrt(spring.k));
ζ = c / (2√k): 1 is critically damped, below it overshoots, above it crawls.
double dampingRatioOf(SpringConfig spring) =>
spring.c / (2 * math.sqrt(spring.k));