Every heroicons icon, as a named constant.
import 'package:stroke_morph_icons/heroicons.dart';
MorphIcon(icon: MorphHeroicons.academicCap);
Each icon is its own static const, so an app links only
the ones it actually names. byName is the one exception —
see its doc.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- academicCap → const NodeIcon
-
The
academic-capicon. - adjustmentsHorizontal → const NodeIcon
-
The
adjustments-horizontalicon. - adjustmentsVertical → const NodeIcon
-
The
adjustments-verticalicon. - archiveBox → const NodeIcon
-
The
archive-boxicon. - archiveBoxArrowDown → const NodeIcon
-
The
archive-box-arrow-downicon. - archiveBoxXMark → const NodeIcon
-
The
archive-box-x-markicon. - arrowDown → const NodeIcon
-
The
arrow-downicon. - arrowDownCircle → const NodeIcon
-
The
arrow-down-circleicon. - arrowDownLeft → const NodeIcon
-
The
arrow-down-lefticon. - arrowDownOnSquare → const NodeIcon
-
The
arrow-down-on-squareicon. - arrowDownOnSquareStack → const NodeIcon
-
The
arrow-down-on-square-stackicon. - arrowDownRight → const NodeIcon
-
The
arrow-down-righticon. - arrowDownTray → const NodeIcon
-
The
arrow-down-trayicon. - arrowLeft → const NodeIcon
-
The
arrow-lefticon. - arrowLeftCircle → const NodeIcon
-
The
arrow-left-circleicon. - arrowLeftEndOnRectangle → const NodeIcon
-
The
arrow-left-end-on-rectangleicon. - arrowLeftOnRectangle → const NodeIcon
-
The
arrow-left-on-rectangleicon. - arrowLeftStartOnRectangle → const NodeIcon
-
The
arrow-left-start-on-rectangleicon. - arrowLongDown → const NodeIcon
-
The
arrow-long-downicon. - arrowLongLeft → const NodeIcon
-
The
arrow-long-lefticon. - arrowLongRight → const NodeIcon
-
The
arrow-long-righticon. - arrowLongUp → const NodeIcon
-
The
arrow-long-upicon. - arrowPath → const NodeIcon
-
The
arrow-pathicon. - arrowPathRoundedSquare → const NodeIcon
-
The
arrow-path-rounded-squareicon. - arrowRight → const NodeIcon
-
The
arrow-righticon. - arrowRightCircle → const NodeIcon
-
The
arrow-right-circleicon. - arrowRightEndOnRectangle → const NodeIcon
-
The
arrow-right-end-on-rectangleicon. - arrowRightOnRectangle → const NodeIcon
-
The
arrow-right-on-rectangleicon. - arrowRightStartOnRectangle → const NodeIcon
-
The
arrow-right-start-on-rectangleicon. - arrowSmallDown → const NodeIcon
-
The
arrow-small-downicon. - arrowSmallLeft → const NodeIcon
-
The
arrow-small-lefticon. - arrowSmallRight → const NodeIcon
-
The
arrow-small-righticon. - arrowSmallUp → const NodeIcon
-
The
arrow-small-upicon. - arrowsPointingIn → const NodeIcon
-
The
arrows-pointing-inicon. - arrowsPointingOut → const NodeIcon
-
The
arrows-pointing-outicon. - arrowsRightLeft → const NodeIcon
-
The
arrows-right-lefticon. - arrowsUpDown → const NodeIcon
-
The
arrows-up-downicon. - arrowTopRightOnSquare → const NodeIcon
-
The
arrow-top-right-on-squareicon. - arrowTrendingDown → const NodeIcon
-
The
arrow-trending-downicon. - arrowTrendingUp → const NodeIcon
-
The
arrow-trending-upicon. - arrowTurnDownLeft → const NodeIcon
-
The
arrow-turn-down-lefticon. - arrowTurnDownRight → const NodeIcon
-
The
arrow-turn-down-righticon. - arrowTurnLeftDown → const NodeIcon
-
The
arrow-turn-left-downicon. - arrowTurnLeftUp → const NodeIcon
-
The
arrow-turn-left-upicon. - arrowTurnRightDown → const NodeIcon
-
The
arrow-turn-right-downicon. - arrowTurnRightUp → const NodeIcon
-
The
arrow-turn-right-upicon. - arrowTurnUpLeft → const NodeIcon
-
The
arrow-turn-up-lefticon. - arrowTurnUpRight → const NodeIcon
-
The
arrow-turn-up-righticon. - arrowUp → const NodeIcon
-
The
arrow-upicon. - arrowUpCircle → const NodeIcon
-
The
arrow-up-circleicon. - arrowUpLeft → const NodeIcon
-
The
arrow-up-lefticon. - arrowUpOnSquare → const NodeIcon
-
The
arrow-up-on-squareicon. - arrowUpOnSquareStack → const NodeIcon
-
The
arrow-up-on-square-stackicon. - arrowUpRight → const NodeIcon
-
The
arrow-up-righticon. - arrowUpTray → const NodeIcon
-
The
arrow-up-trayicon. - arrowUturnDown → const NodeIcon
-
The
arrow-uturn-downicon. - arrowUturnLeft → const NodeIcon
-
The
arrow-uturn-lefticon. - arrowUturnRight → const NodeIcon
-
The
arrow-uturn-righticon. - arrowUturnUp → const NodeIcon
-
The
arrow-uturn-upicon. - atSymbol → const NodeIcon
-
The
at-symbolicon. - backspace → const NodeIcon
-
The
backspaceicon. - backward → const NodeIcon
-
The
backwardicon. - banknotes → const NodeIcon
-
The
banknotesicon. - bars2 → const NodeIcon
-
The
bars-2icon. - bars3 → const NodeIcon
-
The
bars-3icon. - bars3BottomLeft → const NodeIcon
-
The
bars-3-bottom-lefticon. - bars3BottomRight → const NodeIcon
-
The
bars-3-bottom-righticon. - bars3CenterLeft → const NodeIcon
-
The
bars-3-center-lefticon. - bars4 → const NodeIcon
-
The
bars-4icon. - barsArrowDown → const NodeIcon
-
The
bars-arrow-downicon. - barsArrowUp → const NodeIcon
-
The
bars-arrow-upicon. - battery0 → const NodeIcon
-
The
battery-0icon. - battery50 → const NodeIcon
-
The
battery-50icon. - battery100 → const NodeIcon
-
The
battery-100icon. - beaker → const NodeIcon
-
The
beakericon. - bell → const NodeIcon
-
The
bellicon. - bellAlert → const NodeIcon
-
The
bell-alerticon. - bellSlash → const NodeIcon
-
The
bell-slashicon. - bellSnooze → const NodeIcon
-
The
bell-snoozeicon. - bold → const NodeIcon
-
The
boldicon. - bolt → const NodeIcon
-
The
bolticon. - boltSlash → const NodeIcon
-
The
bolt-slashicon. - bookmark → const NodeIcon
-
The
bookmarkicon. - bookmarkSlash → const NodeIcon
-
The
bookmark-slashicon. - bookmarkSquare → const NodeIcon
-
The
bookmark-squareicon. - bookOpen → const NodeIcon
-
The
book-openicon. - briefcase → const NodeIcon
-
The
briefcaseicon. - bugAnt → const NodeIcon
-
The
bug-anticon. - buildingLibrary → const NodeIcon
-
The
building-libraryicon. - buildingOffice → const NodeIcon
-
The
building-officeicon. - buildingOffice2 → const NodeIcon
-
The
building-office-2icon. - buildingStorefront → const NodeIcon
-
The
building-storefronticon. -
byName
→ const Map<
String, MorphIconData> - Every heroicons icon, keyed by its canonical name.
- cake → const NodeIcon
-
The
cakeicon. - calculator → const NodeIcon
-
The
calculatoricon. - calendar → const NodeIcon
-
The
calendaricon. - calendarDateRange → const NodeIcon
-
The
calendar-date-rangeicon. - calendarDays → const NodeIcon
-
The
calendar-daysicon. - camera → const NodeIcon
-
The
cameraicon. - chartBar → const NodeIcon
-
The
chart-baricon. - chartBarSquare → const NodeIcon
-
The
chart-bar-squareicon. - chartPie → const NodeIcon
-
The
chart-pieicon. - chatBubbleBottomCenter → const NodeIcon
-
The
chat-bubble-bottom-centericon. - chatBubbleBottomCenterText → const NodeIcon
-
The
chat-bubble-bottom-center-texticon. - chatBubbleLeft → const NodeIcon
-
The
chat-bubble-lefticon. - chatBubbleLeftEllipsis → const NodeIcon
-
The
chat-bubble-left-ellipsisicon. - chatBubbleLeftRight → const NodeIcon
-
The
chat-bubble-left-righticon. - chatBubbleOvalLeft → const NodeIcon
-
The
chat-bubble-oval-lefticon. - chatBubbleOvalLeftEllipsis → const NodeIcon
-
The
chat-bubble-oval-left-ellipsisicon. - check → const NodeIcon
-
The
checkicon. - checkBadge → const NodeIcon
-
The
check-badgeicon. - checkCircle → const NodeIcon
-
The
check-circleicon. - chevronDoubleDown → const NodeIcon
-
The
chevron-double-downicon. - chevronDoubleLeft → const NodeIcon
-
The
chevron-double-lefticon. - chevronDoubleRight → const NodeIcon
-
The
chevron-double-righticon. - chevronDoubleUp → const NodeIcon
-
The
chevron-double-upicon. - chevronDown → const NodeIcon
-
The
chevron-downicon. - chevronLeft → const NodeIcon
-
The
chevron-lefticon. - chevronRight → const NodeIcon
-
The
chevron-righticon. - chevronUp → const NodeIcon
-
The
chevron-upicon. - chevronUpDown → const NodeIcon
-
The
chevron-up-downicon. - circleStack → const NodeIcon
-
The
circle-stackicon. - clipboard → const NodeIcon
-
The
clipboardicon. - clipboardDocument → const NodeIcon
-
The
clipboard-documenticon. - clipboardDocumentCheck → const NodeIcon
-
The
clipboard-document-checkicon. - clipboardDocumentList → const NodeIcon
-
The
clipboard-document-listicon. - clock → const NodeIcon
-
The
clockicon. - cloud → const NodeIcon
-
The
cloudicon. - cloudArrowDown → const NodeIcon
-
The
cloud-arrow-downicon. - cloudArrowUp → const NodeIcon
-
The
cloud-arrow-upicon. - codeBracket → const NodeIcon
-
The
code-bracketicon. - codeBracketSquare → const NodeIcon
-
The
code-bracket-squareicon. - cog → const NodeIcon
-
The
cogicon. - cog6Tooth → const NodeIcon
-
The
cog-6-toothicon. - cog8Tooth → const NodeIcon
-
The
cog-8-toothicon. - commandLine → const NodeIcon
-
The
command-lineicon. - computerDesktop → const NodeIcon
-
The
computer-desktopicon. - cpuChip → const NodeIcon
-
The
cpu-chipicon. - creditCard → const NodeIcon
-
The
credit-cardicon. - cube → const NodeIcon
-
The
cubeicon. - cubeTransparent → const NodeIcon
-
The
cube-transparenticon. - currencyBangladeshi → const NodeIcon
-
The
currency-bangladeshiicon. - currencyDollar → const NodeIcon
-
The
currency-dollaricon. - currencyEuro → const NodeIcon
-
The
currency-euroicon. - currencyPound → const NodeIcon
-
The
currency-poundicon. - currencyRupee → const NodeIcon
-
The
currency-rupeeicon. - currencyYen → const NodeIcon
-
The
currency-yenicon. - cursorArrowRays → const NodeIcon
-
The
cursor-arrow-raysicon. - cursorArrowRipple → const NodeIcon
-
The
cursor-arrow-rippleicon. - devicePhoneMobile → const NodeIcon
-
The
device-phone-mobileicon. - deviceTablet → const NodeIcon
-
The
device-tableticon. - divide → const NodeIcon
-
The
divideicon. - document → const NodeIcon
-
The
documenticon. - documentArrowDown → const NodeIcon
-
The
document-arrow-downicon. - documentArrowUp → const NodeIcon
-
The
document-arrow-upicon. - documentChartBar → const NodeIcon
-
The
document-chart-baricon. - documentCheck → const NodeIcon
-
The
document-checkicon. - documentCurrencyBangladeshi → const NodeIcon
-
The
document-currency-bangladeshiicon. - documentCurrencyDollar → const NodeIcon
-
The
document-currency-dollaricon. - documentCurrencyEuro → const NodeIcon
-
The
document-currency-euroicon. - documentCurrencyPound → const NodeIcon
-
The
document-currency-poundicon. - documentCurrencyRupee → const NodeIcon
-
The
document-currency-rupeeicon. - documentCurrencyYen → const NodeIcon
-
The
document-currency-yenicon. - documentDuplicate → const NodeIcon
-
The
document-duplicateicon. - documentMagnifyingGlass → const NodeIcon
-
The
document-magnifying-glassicon. - documentMinus → const NodeIcon
-
The
document-minusicon. - documentPlus → const NodeIcon
-
The
document-plusicon. - documentText → const NodeIcon
-
The
document-texticon. - ellipsisHorizontal → const NodeIcon
-
The
ellipsis-horizontalicon. - ellipsisHorizontalCircle → const NodeIcon
-
The
ellipsis-horizontal-circleicon. - ellipsisVertical → const NodeIcon
-
The
ellipsis-verticalicon. - envelope → const NodeIcon
-
The
envelopeicon. - envelopeOpen → const NodeIcon
-
The
envelope-openicon. - equals → const NodeIcon
-
The
equalsicon. - exclamationCircle → const NodeIcon
-
The
exclamation-circleicon. - exclamationTriangle → const NodeIcon
-
The
exclamation-triangleicon. - eye → const NodeIcon
-
The
eyeicon. - eyeDropper → const NodeIcon
-
The
eye-droppericon. - eyeSlash → const NodeIcon
-
The
eye-slashicon. - faceFrown → const NodeIcon
-
The
face-frownicon. - faceSmile → const NodeIcon
-
The
face-smileicon. - film → const NodeIcon
-
The
filmicon. - fingerPrint → const NodeIcon
-
The
finger-printicon. - fire → const NodeIcon
-
The
fireicon. - flag → const NodeIcon
-
The
flagicon. - folder → const NodeIcon
-
The
foldericon. - folderArrowDown → const NodeIcon
-
The
folder-arrow-downicon. - folderMinus → const NodeIcon
-
The
folder-minusicon. - folderOpen → const NodeIcon
-
The
folder-openicon. - folderPlus → const NodeIcon
-
The
folder-plusicon. - forward → const NodeIcon
-
The
forwardicon. - funnel → const NodeIcon
-
The
funnelicon. - gif → const NodeIcon
-
The
gificon. - gift → const NodeIcon
-
The
gifticon. - giftTop → const NodeIcon
-
The
gift-topicon. - globeAlt → const NodeIcon
-
The
globe-alticon. - globeAmericas → const NodeIcon
-
The
globe-americasicon. - globeAsiaAustralia → const NodeIcon
-
The
globe-asia-australiaicon. - globeEuropeAfrica → const NodeIcon
-
The
globe-europe-africaicon. - h1 → const NodeIcon
-
The
h1icon. - h2 → const NodeIcon
-
The
h2icon. - h3 → const NodeIcon
-
The
h3icon. - handRaised → const NodeIcon
-
The
hand-raisedicon. - handThumbDown → const NodeIcon
-
The
hand-thumb-downicon. - handThumbUp → const NodeIcon
-
The
hand-thumb-upicon. - hashtag → const NodeIcon
-
The
hashtagicon. - heart → const NodeIcon
-
The
hearticon. - home → const NodeIcon
-
The
homeicon. - homeModern → const NodeIcon
-
The
home-modernicon. - identification → const NodeIcon
-
The
identificationicon. - inbox → const NodeIcon
-
The
inboxicon. - inboxArrowDown → const NodeIcon
-
The
inbox-arrow-downicon. - inboxStack → const NodeIcon
-
The
inbox-stackicon. - informationCircle → const NodeIcon
-
The
information-circleicon. - italic → const NodeIcon
-
The
italicicon. - key → const NodeIcon
-
The
keyicon. - language → const NodeIcon
-
The
languageicon. - lifebuoy → const NodeIcon
-
The
lifebuoyicon. - lightBulb → const NodeIcon
-
The
light-bulbicon. - link → const NodeIcon
-
The
linkicon. - linkSlash → const NodeIcon
-
The
link-slashicon. - listBullet → const NodeIcon
-
The
list-bulleticon. - lockClosed → const NodeIcon
-
The
lock-closedicon. - lockOpen → const NodeIcon
-
The
lock-openicon. - magnifyingGlass → const NodeIcon
-
The
magnifying-glassicon. - magnifyingGlassCircle → const NodeIcon
-
The
magnifying-glass-circleicon. - magnifyingGlassMinus → const NodeIcon
-
The
magnifying-glass-minusicon. - magnifyingGlassPlus → const NodeIcon
-
The
magnifying-glass-plusicon. - map → const NodeIcon
-
The
mapicon. - mapPin → const NodeIcon
-
The
map-pinicon. - megaphone → const NodeIcon
-
The
megaphoneicon. - microphone → const NodeIcon
-
The
microphoneicon. - minus → const NodeIcon
-
The
minusicon. - minusCircle → const NodeIcon
-
The
minus-circleicon. - minusSmall → const NodeIcon
-
The
minus-smallicon. - moon → const NodeIcon
-
The
moonicon. - musicalNote → const NodeIcon
-
The
musical-noteicon. - newspaper → const NodeIcon
-
The
newspapericon. - noSymbol → const NodeIcon
-
The
no-symbolicon. - numberedList → const NodeIcon
-
The
numbered-listicon. - paintBrush → const NodeIcon
-
The
paint-brushicon. - paperAirplane → const NodeIcon
-
The
paper-airplaneicon. - paperClip → const NodeIcon
-
The
paper-clipicon. - pause → const NodeIcon
-
The
pauseicon. - pauseCircle → const NodeIcon
-
The
pause-circleicon. - pencil → const NodeIcon
-
The
pencilicon. - pencilSquare → const NodeIcon
-
The
pencil-squareicon. - percentBadge → const NodeIcon
-
The
percent-badgeicon. - phone → const NodeIcon
-
The
phoneicon. - phoneArrowDownLeft → const NodeIcon
-
The
phone-arrow-down-lefticon. - phoneArrowUpRight → const NodeIcon
-
The
phone-arrow-up-righticon. - phoneXMark → const NodeIcon
-
The
phone-x-markicon. - photo → const NodeIcon
-
The
photoicon. - play → const NodeIcon
-
The
playicon. - playCircle → const NodeIcon
-
The
play-circleicon. - playPause → const NodeIcon
-
The
play-pauseicon. - plus → const NodeIcon
-
The
plusicon. - plusCircle → const NodeIcon
-
The
plus-circleicon. - plusSmall → const NodeIcon
-
The
plus-smallicon. - power → const NodeIcon
-
The
powericon. - presentationChartBar → const NodeIcon
-
The
presentation-chart-baricon. - presentationChartLine → const NodeIcon
-
The
presentation-chart-lineicon. - printer → const NodeIcon
-
The
printericon. - puzzlePiece → const NodeIcon
-
The
puzzle-pieceicon. - qrCode → const NodeIcon
-
The
qr-codeicon. - questionMarkCircle → const NodeIcon
-
The
question-mark-circleicon. - queueList → const NodeIcon
-
The
queue-listicon. - radio → const NodeIcon
-
The
radioicon. - receiptPercent → const NodeIcon
-
The
receipt-percenticon. - receiptRefund → const NodeIcon
-
The
receipt-refundicon. - rectangleGroup → const NodeIcon
-
The
rectangle-groupicon. - rectangleStack → const NodeIcon
-
The
rectangle-stackicon. - rocketLaunch → const NodeIcon
-
The
rocket-launchicon. - rss → const NodeIcon
-
The
rssicon. - scale → const NodeIcon
-
The
scaleicon. - scissors → const NodeIcon
-
The
scissorsicon. - server → const NodeIcon
-
The
servericon. - serverStack → const NodeIcon
-
The
server-stackicon. -
The
shareicon. - shieldCheck → const NodeIcon
-
The
shield-checkicon. - shieldExclamation → const NodeIcon
-
The
shield-exclamationicon. - shoppingBag → const NodeIcon
-
The
shopping-bagicon. - shoppingCart → const NodeIcon
-
The
shopping-carticon. - signal → const NodeIcon
-
The
signalicon. - signalSlash → const NodeIcon
-
The
signal-slashicon. - slash → const NodeIcon
-
The
slashicon. - sparkles → const NodeIcon
-
The
sparklesicon. - speakerWave → const NodeIcon
-
The
speaker-waveicon. - speakerXMark → const NodeIcon
-
The
speaker-x-markicon. - square2Stack → const NodeIcon
-
The
square-2-stackicon. - square3Stack3d → const NodeIcon
-
The
square-3-stack-3dicon. - squares2x2 → const NodeIcon
-
The
squares-2x2icon. - squaresPlus → const NodeIcon
-
The
squares-plusicon. - star → const NodeIcon
-
The
staricon. - stop → const NodeIcon
-
The
stopicon. - stopCircle → const NodeIcon
-
The
stop-circleicon. - strikethrough → const NodeIcon
-
The
strikethroughicon. - sun → const NodeIcon
-
The
sunicon. - swatch → const NodeIcon
-
The
swatchicon. - tableCells → const NodeIcon
-
The
table-cellsicon. - tag → const NodeIcon
-
The
tagicon. - ticket → const NodeIcon
-
The
ticketicon. - trash → const NodeIcon
-
The
trashicon. - trophy → const NodeIcon
-
The
trophyicon. - truck → const NodeIcon
-
The
truckicon. - tv → const NodeIcon
-
The
tvicon. - underline → const NodeIcon
-
The
underlineicon. - user → const NodeIcon
-
The
usericon. - userCircle → const NodeIcon
-
The
user-circleicon. - userGroup → const NodeIcon
-
The
user-groupicon. - userMinus → const NodeIcon
-
The
user-minusicon. - userPlus → const NodeIcon
-
The
user-plusicon. - users → const NodeIcon
-
The
usersicon. - variable → const NodeIcon
-
The
variableicon. - videoCamera → const NodeIcon
-
The
video-cameraicon. - videoCameraSlash → const NodeIcon
-
The
video-camera-slashicon. - viewColumns → const NodeIcon
-
The
view-columnsicon. - viewfinderCircle → const NodeIcon
-
The
viewfinder-circleicon. - wallet → const NodeIcon
-
The
walleticon. - wifi → const NodeIcon
-
The
wifiicon. - window → const NodeIcon
-
The
windowicon. - wrench → const NodeIcon
-
The
wrenchicon. - wrenchScrewdriver → const NodeIcon
-
The
wrench-screwdrivericon. - xCircle → const NodeIcon
-
The
x-circleicon. - xMark → const NodeIcon
-
The
x-markicon.