CubicPath class final
Normalized subpath: a chain of cubics packed as points
[p0, c1, c2, p1, c1', c2', p2, …] → a Float64List of length 2·(3m+1),
with m the number of segments. Consecutive segments share an endpoint.
Constructors
- CubicPath(Float64List pts, bool closed)
Properties
- closed → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pts ↔ Float64List
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- segCount → int
-
Number of cubic segments.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited