label property
Accessibility: with a label the icon is exposed as an image; without one
it is hidden from assistive technology (the analogue of aria-hidden).
Implementation
final String? label;
Accessibility: with a label the icon is exposed as an image; without one
it is hidden from assistive technology (the analogue of aria-hidden).
final String? label;