Spring class
Properties
-
c
↔ double
-
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
k
↔ double
-
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
v
↔ double
-
getter/setter pair
-
x
↔ double
-
getter/setter pair
Methods
-
config(double k, double c)
→ void
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
start()
→ void
-
Starts (or restarts mid-flight) preserving velocity.
-
step(double dt)
→ bool
-
Advances
dt seconds. Returns true on settle (|1−x| < 0.001 ∧ |v| < 0.02).
-
toString()
→ String
-
A string representation of this object.
inherited